@@ -58,6 +58,7 @@ def _resolve_filter_classes(cls_list):
 
         try:
             cls = getattr(module, cdef[cdef.rfind('.') + 1:])
+
             if inspect.isclass(cls):
                 filter_cls_list.append(cls)
             elif inspect.isfunction(cls):
@@ -72,6 +73,8 @@ def _resolve_filter_classes(cls_list):
         except AttributeError as ae:
             _LOG.exception(ae)
             raise ImportError('Unable to import: {}'.format(cdef))
+
+    _LOG.debug('Found filters: {}'.format(filter_cls_list))
     return filter_cls_list
 
 
@@ -103,6 +106,8 @@ def _build_singleton_plfactories(config):
     all_classes.extend(_resolve_filter_classes(config.pipeline.upstream))
     all_classes.extend(_resolve_filter_classes(config.pipeline.downstream))
 
+    _LOG.debug('Gathered filter classes: {}'.format(all_classes))
+
     for cls in all_classes:
         filter_instances[cls.__name__] = cls()
 
@@ -118,6 +123,10 @@ def _build_plfactories(config):
         _resolve_filter_classes(config.pipeline.upstream))
     downstream = _build_plfactory_closure(
         _resolve_filter_classes(config.pipeline.downstream))
+
+    _LOG.debug('Gathered upstream filter classes: {}'.format(upstream()))
+    _LOG.debug('Gathered downstream filter classes: {}'.format(downstream()))
+
     return upstream, downstream
 
 
